==> proc-10.1.27.tar.gz: proc/src/Controller/ProcController.php <==
<?php

namespace Drupal\proc\Controller;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Access\AccessResultAllowed;
use Drupal\Core\Access\AccessResultForbidden;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Path\CurrentPathStack;
use Drupal\Core\Session\AccountProxy;
use Drupal\proc\Entity\Proc;
use Drupal\proc\Traits\ProcRecipientTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Controller.
 */
class ProcController extends ControllerBase {

  use ProcRecipientTrait;

  /**
   * The current user.
   *
   * @var \Drupal\Core\Session\AccountProxy
   */
  protected AccountProxy $current_user;

  /**
   * The current path.
   *
   * @var \Drupal\Core\Path\CurrentPathStack
   */
  protected CurrentPathStack $current_path;

  /**
   * ProcController controller.
   *
   * @param \Drupal\Core\Session\AccountProxy $current_user
   *   The file repository.
   *
   * @param \Drupal\Core\Path\CurrentPathStack $current_path
   *   The current path.
   */
  public function __construct(AccountProxy $current_user, CurrentPathStack $current_path) {
    $this->currentUser = $current_user;
    $this->currentPath = $current_path;
  }

  /**
   * {@inheritdoc}
   *
   * @param \Symfony\Component\DependencyInjection\ContainerInterface $container
   *   The Drupal service container.
   *
   * @return static
   */
  public static function create(ContainerInterface $container): static {
    return new static(
      $container->get('current_user'),
      $container->get('path.current')
    );
  }

  /**
   * Checks whether the user is a possible recipient for a PGP message.
   *
   * @param string $users
   *   User IDs as CSV.
   *
   * @return \Drupal\Core\Access\AccessResultForbidden
   *   Controller response.
   */
  public function checkRecipientsCsvController($users) {
    $rejected_recipient_candidate = $this->checkRecipientsCsv($users);
    $auto_filter_recipients = $this->config('proc.settings')->get('proc-auto-filter-recipients') ?? 0;
    switch ($auto_filter_recipients) {
      // Restrictive strategy.
      case 0:
        if (!is_int($rejected_recipient_candidate) && $rejected_recipient_candidate != FALSE) {
          return AccessResult::allowed();
        }
        return AccessResult::forbidden(
          $this->t('User account %rejected_recipient_candidate does not exist or user is not a holder of PGP keys.', [
            '%rejected_recipient_candidate' => $rejected_recipient_candidate,
          ]));

      break;

      // Permissive strategy.
      case 1:
        return AccessResult::allowed();

      break;
    }
  }

  /**
   * Checks whether the current user is listed as recipient of proc entity.
   */
  public function checkCurrentUserIsRecipient(): AccessResultForbidden|AccessResultAllowed {
    // Get the current user.
    $current_user = $this->currentUser->id();
    // Get proc ID from current path.
    $current_path = $this->currentPath->getPath();

    if ($current_path == '/proc/generate-keys') {
      return AccessResult::allowed();
    }

    $proc_id = str_replace('/proc/', '', $current_path);
    if (!is_numeric($proc_id)) {
      // Edit page:
      $proc_id = substr($proc_id, 0, strpos($proc_id, "/"));
      // Grant access if user is author or admin.
      if (is_numeric($proc_id)) {
        $proc = Proc::load($proc_id);
        if (
          ($proc->getOwnerId() == $current_user && $this->currentUser->hasPermission('edit proc entity')) ||
          $this->currentUser->hasPermission('administer proc entity')
        ) {
          return AccessResult::allowed();
        }
      }
    }
    // Load proc entity by proc ID.
    $proc = Proc::load($proc_id);
    if ($proc instanceof Proc) {
      // Get the recipients of the proc entity.
      $recipients = $proc->get('field_recipients_set')->getValue();

      foreach ($recipients as $recipient) {
        if ($recipient['target_id'] == $current_user) {
          return AccessResult::allowed();
        }
      }
    }

    return AccessResult::forbidden();
  }

}

==> proc-10.1.36.tar.gz: proc/src/Controller/ProcController.php <==
<?php

namespace Drupal\proc\Controller;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Access\AccessResultAllowed;
use Drupal\Core\Access\AccessResultForbidden;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Path\CurrentPathStack;
use Drupal\Core\Session\AccountProxy;
use Drupal\proc\Entity\Proc;
use Drupal\proc\ProcInterface;
use Drupal\proc\Traits\ProcRecipientTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Controller.
 */
class ProcController extends ControllerBase {

  use ProcRecipientTrait;

  /**
   * The current path.
   *
   * @var \Drupal\Core\Path\CurrentPathStack
   */
  protected CurrentPathStack $currentPath;

  /**
   * ProcController controller.
   *
   * @param \Drupal\Core\Session\AccountProxy $current_user
   *   The file repository.
   * @param \Drupal\Core\Path\CurrentPathStack $current_path
   *   The current path.
   */
  public function __construct(AccountProxy $current_user, CurrentPathStack $current_path) {
    $this->currentUser = $current_user;
    $this->currentPath = $current_path;
  }

  /**
   * {@inheritdoc}
   *
   * @param \Symfony\Component\DependencyInjection\ContainerInterface $container
   *   The Drupal service container.
   *
   * @return static
   */
  public static function create(ContainerInterface $container): static {
    return new static(
      $container->get('current_user'),
      $container->get('path.current')
    );
  }

  /**
   * Checks whether the user is a possible recipient for a PGP message.
   *
   * @param string $users
   *   User IDs as CSV.
   *
   * @return \Drupal\Core\Access\AccessResultForbidden
   *   Controller response.
   */
  public function checkRecipientsCsvController($users) {
    $rejected_recipient_candidate = $this->checkRecipientsCsv($users);
    $auto_filter_recipients = $this->config('proc.settings')->get('proc-auto-filter-recipients') ?? 0;
    switch ($auto_filter_recipients) {
      case ProcInterface::STRATEGY_RESTRICTIVE:
        if (!is_int($rejected_recipient_candidate) && $rejected_recipient_candidate != FALSE) {
          return AccessResult::allowed();
        }
        return AccessResult::forbidden(
          $this->t('User account %rejected_recipient_candidate does not exist or user is not a holder of PGP keys.', [
            '%rejected_recipient_candidate' => $rejected_recipient_candidate,
          ]));

      case ProcInterface::STRATEGY_PERMISSIVE:
        return AccessResult::allowed();
    }
  }

  /**
   * Checks whether the current user is listed as recipient of proc entity.
   */
  public function checkCurrentUserIsRecipient(): AccessResultForbidden|AccessResultAllowed {
    // Get the current user.
    $current_user = $this->currentUser->id();
    // Get proc ID from current path.
    $current_path = $this->currentPath->getPath();

    if ($current_path == '/proc/generate-keys') {
      return AccessResult::allowed();
    }

    $proc_id = str_replace('/proc/', '', $current_path);
    if (!is_numeric($proc_id)) {
      // Edit page:
      $proc_id = mb_substr($proc_id, 0, strpos($proc_id, "/"));
      // Grant access if user is author or admin.
      if (is_numeric($proc_id)) {
        $proc = Proc::load($proc_id);
        if (
          ($proc->getOwnerId() == $current_user && $this->currentUser->hasPermission('edit proc entity')) ||
          $this->currentUser->hasPermission('administer proc entity')
        ) {
          return AccessResult::allowed();
        }
      }
    }
    // Load proc entity by proc ID.
    $proc = Proc::load($proc_id);
    if ($proc instanceof Proc) {
      // Get the recipients of the proc entity.
      $recipients = $proc->get('field_recipients_set')->getValue();

      foreach ($recipients as $recipient) {
        if ($recipient['target_id'] == $current_user) {
          return AccessResult::allowed();
        }
      }
    }

    return AccessResult::forbidden();
  }

}
